# <span class="badge package-variant-dataquery"></span> elasticsearch

## Objects

 * <span class="badge object-type-class"></span> [Average](./object-Average.md)
 * <span class="badge object-type-class"></span> [BaseBucketAggregation](./object-BaseBucketAggregation.md)
 * <span class="badge object-type-class"></span> [BaseMetricAggregation](./object-BaseMetricAggregation.md)
 * <span class="badge object-type-class"></span> [BaseMovingAverageModelSettings](./object-BaseMovingAverageModelSettings.md)
 * <span class="badge object-type-class"></span> [BasePipelineMetricAggregation](./object-BasePipelineMetricAggregation.md)
 * <span class="badge object-type-disjunction"></span> [BucketAggregation](./object-BucketAggregation.md)
 * <span class="badge object-type-enum"></span> [BucketAggregationType](./object-BucketAggregationType.md)
 * <span class="badge object-type-class"></span> [BucketAggregationWithField](./object-BucketAggregationWithField.md)
 * <span class="badge object-type-class"></span> [BucketScript](./object-BucketScript.md)
 * <span class="badge object-type-class"></span> [Count](./object-Count.md)
 * <span class="badge object-type-class"></span> [CumulativeSum](./object-CumulativeSum.md)
 * <span class="badge object-type-class"></span> [DateHistogram](./object-DateHistogram.md)
 * <span class="badge object-type-class"></span> [DateHistogramSettings](./object-DateHistogramSettings.md)
 * <span class="badge object-type-class"></span> [Derivative](./object-Derivative.md)
 * <span class="badge object-type-class"></span> [ElasticsearchAverageSettings](./object-ElasticsearchAverageSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchBucketScriptSettings](./object-ElasticsearchBucketScriptSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchCumulativeSumSettings](./object-ElasticsearchCumulativeSumSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchDateHistogramSettings](./object-ElasticsearchDateHistogramSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchDerivativeSettings](./object-ElasticsearchDerivativeSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchExtendedStatsSettings](./object-ElasticsearchExtendedStatsSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchFiltersSettings](./object-ElasticsearchFiltersSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchGeoHashGridSettings](./object-ElasticsearchGeoHashGridSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchHistogramSettings](./object-ElasticsearchHistogramSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchInlineScript](./object-ElasticsearchInlineScript.md)
 * <span class="badge object-type-class"></span> [ElasticsearchLogsSettings](./object-ElasticsearchLogsSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMaxSettings](./object-ElasticsearchMaxSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMetricAggregationWithInlineScriptSettings](./object-ElasticsearchMetricAggregationWithInlineScriptSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMetricAggregationWithMissingSupportSettings](./object-ElasticsearchMetricAggregationWithMissingSupportSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMinSettings](./object-ElasticsearchMinSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMovingAverageEWMAModelSettingsSettings](./object-ElasticsearchMovingAverageEWMAModelSettingsSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMovingAverageHoltModelSettingsSettings](./object-ElasticsearchMovingAverageHoltModelSettingsSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMovingAverageHoltWintersModelSettingsSettings](./object-ElasticsearchMovingAverageHoltWintersModelSettingsSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchMovingFunctionSettings](./object-ElasticsearchMovingFunctionSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchPercentilesSettings](./object-ElasticsearchPercentilesSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchRateSettings](./object-ElasticsearchRateSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchRawDataSettings](./object-ElasticsearchRawDataSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchRawDocumentSettings](./object-ElasticsearchRawDocumentSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchSerialDiffSettings](./object-ElasticsearchSerialDiffSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchSumSettings](./object-ElasticsearchSumSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchTermsSettings](./object-ElasticsearchTermsSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchTopMetricsSettings](./object-ElasticsearchTopMetricsSettings.md)
 * <span class="badge object-type-class"></span> [ElasticsearchUniqueCountSettings](./object-ElasticsearchUniqueCountSettings.md)
 * <span class="badge object-type-class"></span> [ExtendedStat](./object-ExtendedStat.md)
 * <span class="badge object-type-enum"></span> [ExtendedStatMetaType](./object-ExtendedStatMetaType.md)
 * <span class="badge object-type-class"></span> [ExtendedStats](./object-ExtendedStats.md)
 * <span class="badge object-type-class"></span> [Filter](./object-Filter.md)
 * <span class="badge object-type-class"></span> [Filters](./object-Filters.md)
 * <span class="badge object-type-class"></span> [FiltersSettings](./object-FiltersSettings.md)
 * <span class="badge object-type-class"></span> [GeoHashGrid](./object-GeoHashGrid.md)
 * <span class="badge object-type-class"></span> [GeoHashGridSettings](./object-GeoHashGridSettings.md)
 * <span class="badge object-type-class"></span> [Histogram](./object-Histogram.md)
 * <span class="badge object-type-class"></span> [HistogramSettings](./object-HistogramSettings.md)
 * <span class="badge object-type-disjunction"></span> [InlineScript](./object-InlineScript.md)
 * <span class="badge object-type-class"></span> [Logs](./object-Logs.md)
 * <span class="badge object-type-class"></span> [Max](./object-Max.md)
 * <span class="badge object-type-disjunction"></span> [MetricAggregation](./object-MetricAggregation.md)
 * <span class="badge object-type-enum"></span> [MetricAggregationType](./object-MetricAggregationType.md)
 * <span class="badge object-type-class"></span> [MetricAggregationWithField](./object-MetricAggregationWithField.md)
 * <span class="badge object-type-class"></span> [MetricAggregationWithInlineScript](./object-MetricAggregationWithInlineScript.md)
 * <span class="badge object-type-class"></span> [MetricAggregationWithMissingSupport](./object-MetricAggregationWithMissingSupport.md)
 * <span class="badge object-type-disjunction"></span> [MetricAggregationWithSettings](./object-MetricAggregationWithSettings.md)
 * <span class="badge object-type-class"></span> [Min](./object-Min.md)
 * <span class="badge object-type-class"></span> [MovingAverage](./object-MovingAverage.md)
 * <span class="badge object-type-class"></span> [MovingAverageEWMAModelSettings](./object-MovingAverageEWMAModelSettings.md)
 * <span class="badge object-type-class"></span> [MovingAverageHoltModelSettings](./object-MovingAverageHoltModelSettings.md)
 * <span class="badge object-type-class"></span> [MovingAverageHoltWintersModelSettings](./object-MovingAverageHoltWintersModelSettings.md)
 * <span class="badge object-type-class"></span> [MovingAverageLinearModelSettings](./object-MovingAverageLinearModelSettings.md)
 * <span class="badge object-type-enum"></span> [MovingAverageModel](./object-MovingAverageModel.md)
 * <span class="badge object-type-class"></span> [MovingAverageModelOption](./object-MovingAverageModelOption.md)
 * <span class="badge object-type-class"></span> [MovingAverageSimpleModelSettings](./object-MovingAverageSimpleModelSettings.md)
 * <span class="badge object-type-class"></span> [MovingFunction](./object-MovingFunction.md)
 * <span class="badge object-type-class"></span> [Nested](./object-Nested.md)
 * <span class="badge object-type-class"></span> [Percentiles](./object-Percentiles.md)
 * <span class="badge object-type-disjunction"></span> [PipelineMetricAggregation](./object-PipelineMetricAggregation.md)
 * <span class="badge object-type-enum"></span> [PipelineMetricAggregationType](./object-PipelineMetricAggregationType.md)
 * <span class="badge object-type-class"></span> [PipelineMetricAggregationWithMultipleBucketPaths](./object-PipelineMetricAggregationWithMultipleBucketPaths.md)
 * <span class="badge object-type-class"></span> [PipelineVariable](./object-PipelineVariable.md)
 * <span class="badge object-type-class"></span> [Rate](./object-Rate.md)
 * <span class="badge object-type-class"></span> [RawData](./object-RawData.md)
 * <span class="badge object-type-class"></span> [RawDocument](./object-RawDocument.md)
 * <span class="badge object-type-class"></span> [SerialDiff](./object-SerialDiff.md)
 * <span class="badge object-type-class"></span> [Sum](./object-Sum.md)
 * <span class="badge object-type-class"></span> [Terms](./object-Terms.md)
 * <span class="badge object-type-enum"></span> [TermsOrder](./object-TermsOrder.md)
 * <span class="badge object-type-class"></span> [TermsSettings](./object-TermsSettings.md)
 * <span class="badge object-type-class"></span> [TopMetrics](./object-TopMetrics.md)
 * <span class="badge object-type-class"></span> [UniqueCount](./object-UniqueCount.md)
 * <span class="badge object-type-class"></span> [Dataquery](./object-Dataquery.md)
## Builders

 * <span class="badge builder"></span> [Average](./builder-Average.md)
 * <span class="badge builder"></span> [BaseBucketAggregation](./builder-BaseBucketAggregation.md)
 * <span class="badge builder"></span> [BaseMetricAggregation](./builder-BaseMetricAggregation.md)
 * <span class="badge builder"></span> [BaseMovingAverageModelSettings](./builder-BaseMovingAverageModelSettings.md)
 * <span class="badge builder"></span> [BasePipelineMetricAggregation](./builder-BasePipelineMetricAggregation.md)
 * <span class="badge builder"></span> [BucketAggregationWithField](./builder-BucketAggregationWithField.md)
 * <span class="badge builder"></span> [BucketScript](./builder-BucketScript.md)
 * <span class="badge builder"></span> [Count](./builder-Count.md)
 * <span class="badge builder"></span> [CumulativeSum](./builder-CumulativeSum.md)
 * <span class="badge builder"></span> [DateHistogram](./builder-DateHistogram.md)
 * <span class="badge builder"></span> [DateHistogramSettings](./builder-DateHistogramSettings.md)
 * <span class="badge builder"></span> [Derivative](./builder-Derivative.md)
 * <span class="badge builder"></span> [ElasticsearchAverageSettings](./builder-ElasticsearchAverageSettings.md)
 * <span class="badge builder"></span> [ElasticsearchBucketScriptSettings](./builder-ElasticsearchBucketScriptSettings.md)
 * <span class="badge builder"></span> [ElasticsearchCumulativeSumSettings](./builder-ElasticsearchCumulativeSumSettings.md)
 * <span class="badge builder"></span> [ElasticsearchDateHistogramSettings](./builder-ElasticsearchDateHistogramSettings.md)
 * <span class="badge builder"></span> [ElasticsearchDerivativeSettings](./builder-ElasticsearchDerivativeSettings.md)
 * <span class="badge builder"></span> [ElasticsearchExtendedStatsSettings](./builder-ElasticsearchExtendedStatsSettings.md)
 * <span class="badge builder"></span> [ElasticsearchFiltersSettings](./builder-ElasticsearchFiltersSettings.md)
 * <span class="badge builder"></span> [ElasticsearchGeoHashGridSettings](./builder-ElasticsearchGeoHashGridSettings.md)
 * <span class="badge builder"></span> [ElasticsearchHistogramSettings](./builder-ElasticsearchHistogramSettings.md)
 * <span class="badge builder"></span> [ElasticsearchInlineScript](./builder-ElasticsearchInlineScript.md)
 * <span class="badge builder"></span> [ElasticsearchLogsSettings](./builder-ElasticsearchLogsSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMaxSettings](./builder-ElasticsearchMaxSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMetricAggregationWithInlineScriptSettings](./builder-ElasticsearchMetricAggregationWithInlineScriptSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMetricAggregationWithMissingSupportSettings](./builder-ElasticsearchMetricAggregationWithMissingSupportSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMinSettings](./builder-ElasticsearchMinSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMovingAverageEWMAModelSettingsSettings](./builder-ElasticsearchMovingAverageEWMAModelSettingsSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMovingAverageHoltModelSettingsSettings](./builder-ElasticsearchMovingAverageHoltModelSettingsSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMovingAverageHoltWintersModelSettingsSettings](./builder-ElasticsearchMovingAverageHoltWintersModelSettingsSettings.md)
 * <span class="badge builder"></span> [ElasticsearchMovingFunctionSettings](./builder-ElasticsearchMovingFunctionSettings.md)
 * <span class="badge builder"></span> [ElasticsearchPercentilesSettings](./builder-ElasticsearchPercentilesSettings.md)
 * <span class="badge builder"></span> [ElasticsearchRateSettings](./builder-ElasticsearchRateSettings.md)
 * <span class="badge builder"></span> [ElasticsearchRawDataSettings](./builder-ElasticsearchRawDataSettings.md)
 * <span class="badge builder"></span> [ElasticsearchRawDocumentSettings](./builder-ElasticsearchRawDocumentSettings.md)
 * <span class="badge builder"></span> [ElasticsearchSerialDiffSettings](./builder-ElasticsearchSerialDiffSettings.md)
 * <span class="badge builder"></span> [ElasticsearchSumSettings](./builder-ElasticsearchSumSettings.md)
 * <span class="badge builder"></span> [ElasticsearchTermsSettings](./builder-ElasticsearchTermsSettings.md)
 * <span class="badge builder"></span> [ElasticsearchTopMetricsSettings](./builder-ElasticsearchTopMetricsSettings.md)
 * <span class="badge builder"></span> [ElasticsearchUniqueCountSettings](./builder-ElasticsearchUniqueCountSettings.md)
 * <span class="badge builder"></span> [ExtendedStat](./builder-ExtendedStat.md)
 * <span class="badge builder"></span> [ExtendedStats](./builder-ExtendedStats.md)
 * <span class="badge builder"></span> [Filter](./builder-Filter.md)
 * <span class="badge builder"></span> [Filters](./builder-Filters.md)
 * <span class="badge builder"></span> [FiltersSettings](./builder-FiltersSettings.md)
 * <span class="badge builder"></span> [GeoHashGrid](./builder-GeoHashGrid.md)
 * <span class="badge builder"></span> [GeoHashGridSettings](./builder-GeoHashGridSettings.md)
 * <span class="badge builder"></span> [Histogram](./builder-Histogram.md)
 * <span class="badge builder"></span> [HistogramSettings](./builder-HistogramSettings.md)
 * <span class="badge builder"></span> [Logs](./builder-Logs.md)
 * <span class="badge builder"></span> [Max](./builder-Max.md)
 * <span class="badge builder"></span> [MetricAggregationWithField](./builder-MetricAggregationWithField.md)
 * <span class="badge builder"></span> [MetricAggregationWithInlineScript](./builder-MetricAggregationWithInlineScript.md)
 * <span class="badge builder"></span> [MetricAggregationWithMissingSupport](./builder-MetricAggregationWithMissingSupport.md)
 * <span class="badge builder"></span> [Min](./builder-Min.md)
 * <span class="badge builder"></span> [MovingAverage](./builder-MovingAverage.md)
 * <span class="badge builder"></span> [MovingAverageEWMAModelSettings](./builder-MovingAverageEWMAModelSettings.md)
 * <span class="badge builder"></span> [MovingAverageHoltModelSettings](./builder-MovingAverageHoltModelSettings.md)
 * <span class="badge builder"></span> [MovingAverageHoltWintersModelSettings](./builder-MovingAverageHoltWintersModelSettings.md)
 * <span class="badge builder"></span> [MovingAverageLinearModelSettings](./builder-MovingAverageLinearModelSettings.md)
 * <span class="badge builder"></span> [MovingAverageModelOption](./builder-MovingAverageModelOption.md)
 * <span class="badge builder"></span> [MovingAverageSimpleModelSettings](./builder-MovingAverageSimpleModelSettings.md)
 * <span class="badge builder"></span> [MovingFunction](./builder-MovingFunction.md)
 * <span class="badge builder"></span> [Nested](./builder-Nested.md)
 * <span class="badge builder"></span> [Percentiles](./builder-Percentiles.md)
 * <span class="badge builder"></span> [PipelineMetricAggregationWithMultipleBucketPaths](./builder-PipelineMetricAggregationWithMultipleBucketPaths.md)
 * <span class="badge builder"></span> [PipelineVariable](./builder-PipelineVariable.md)
 * <span class="badge builder"></span> [Rate](./builder-Rate.md)
 * <span class="badge builder"></span> [RawData](./builder-RawData.md)
 * <span class="badge builder"></span> [RawDocument](./builder-RawDocument.md)
 * <span class="badge builder"></span> [SerialDiff](./builder-SerialDiff.md)
 * <span class="badge builder"></span> [Sum](./builder-Sum.md)
 * <span class="badge builder"></span> [Terms](./builder-Terms.md)
 * <span class="badge builder"></span> [TermsSettings](./builder-TermsSettings.md)
 * <span class="badge builder"></span> [TopMetrics](./builder-TopMetrics.md)
 * <span class="badge builder"></span> [UniqueCount](./builder-UniqueCount.md)
 * <span class="badge builder"></span> [Dataquery](./builder-Dataquery.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to elasticsearch data queries.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.DataqueryConfig
```

